#-----------------------------------------------------------------------------
#
# VTKEdgeConfig.cmake - CMake configuration file for external projects.
#
# This file is configured by VTKEdge and used by the UseVTKEdge.cmake 
# module to load VTKEdge's settings for an external project.

# Compute the installation prefix from VTKEdge_DIR.
set(VTKEdge_INSTALL_PREFIX "${VTKEdge_DIR}")
GET_FILENAME_COMPONENT(VTKEdge_INSTALL_PREFIX "${VTKEdge_INSTALL_PREFIX}" PATH)
GET_FILENAME_COMPONENT(VTKEdge_INSTALL_PREFIX "${VTKEdge_INSTALL_PREFIX}" PATH)

# The VTKEdge version number.
set(VTKEdge_VERSION_MAJOR  "0")
set(VTKEdge_VERSION_MINOR  "1")
set(VTKEdge_VERSION_BUILD  "0")
set(VTKEdge_VERSION        "0.1.0")

# The libraries.
set(VTKEdge_LIBRARIES "vtkKWECommon;vtkKWEFiltering;vtkKWEGraphics;vtkKWEHybrid;vtkKWEImaging;vtkKWEIO;vtkKWERendering;vtkKWEVolumeRendering;vtkKWEWidgets")

# The CMake macros dir.
set(VTKEdge_CMAKE_DIR "${VTKEdge_INSTALL_PREFIX}/lib//VTKEdge/CMake")

# The configuration options.
set(VTKEdge_BUILD_SHARED_LIBS         "1")
set(VTKEdge_BUILD_EXAMPLES            "OFF")
set(VTKEdge_BUILD_PARAVIEW_PLUGINS    "OFF")

set(VTKEdge_USE_CUDA                  "OFF")
set(VTKEdge_USE_DIRECTX               "")
set(VTKEdge_USE_CORE_GRAPHICS         "")
set(VTKEdge_USE_NVCONTROL             "OFF")

set(VTKEdge_USE_ITK                   "ON")

set(VTKEdge_AVAILABLE_KITS            "Common;Filtering;Graphics;Hybrid;Imaging;IO;Rendering;VolumeRendering;Widgets")
set(VTKEdge_ENABLED_KITS              "Common;Filtering;Graphics;Hybrid;Imaging;IO;Rendering;VolumeRendering;Widgets")

set(VTKEdge_BUILD_Common_KIT          "ON")
set(VTKEdge_BUILD_Filtering_KIT       "ON")
set(VTKEdge_BUILD_Graphics_KIT        "ON")
set(VTKEdge_BUILD_Hybrid_KIT          "ON")
set(VTKEdge_BUILD_Imaging_KIT         "ON")
set(VTKEdge_BUILD_IO_KIT              "ON")
set(VTKEdge_BUILD_Rendering_KIT       "ON")
set(VTKEdge_BUILD_VolumeRendering_KIT "ON")
set(VTKEdge_BUILD_Widgets_KIT         "ON")
set(VTKEdge_PAINTBRUSH_LABEL_TYPE     "VTK_UNSIGNED_SHORT")

# The C and C++ flags added to the cmake-configured flags.
set(VTKEdge_REQUIRED_C_FLAGS 
  "")
set(VTKEdge_REQUIRED_CXX_FLAGS 
  "")
set(VTKEdge_REQUIRED_EXE_LINKER_FLAGS 
  "")
set(VTKEdge_REQUIRED_SHARED_LINKER_FLAGS 
  "")
set(VTKEdge_REQUIRED_MODULE_LINKER_FLAGS 
  "")

# The "use" file.
set(VTKEdge_USE_FILE "${VTKEdge_INSTALL_PREFIX}/lib//VTKEdge/UseVTKEdge.cmake")

# The build settings file.
set(VTKEdge_BUILD_SETTINGS_FILE "${VTKEdge_INSTALL_PREFIX}/lib//VTKEdge/VTKEdgeBuildSettings.cmake")

# The library directories.
set(VTKEdge_LIBRARY_DIRS "${VTKEdge_INSTALL_PREFIX}/lib/")

# The runtime directories.
# Note that if VTKEdge_CONFIGURATION_TYPES is set (see below) then
# these directories will be the parent directories under which there will
# be a directory of runtime binaries for each configuration type.
set(VTKEdge_RUNTIME_DIRS "${VTKEdge_INSTALL_PREFIX}/lib/")

# The include directories.
set(VTKEdge_INCLUDE_DIRS "${VTKEdge_INSTALL_PREFIX}/include/VTKEdge")

# The library dependencies file.
if(NOT VTKEdge_NO_LIBRARY_DEPENDS AND
    EXISTS "${VTKEdge_INSTALL_PREFIX}/lib//VTKEdge/VTKEdgeLibraryDepends.cmake")
  include("${VTKEdge_INSTALL_PREFIX}/lib//VTKEdge/VTKEdgeLibraryDepends.cmake")
endif(NOT VTKEdge_NO_LIBRARY_DEPENDS AND
  EXISTS "${VTKEdge_INSTALL_PREFIX}/lib//VTKEdge/VTKEdgeLibraryDepends.cmake")

# The VTK options.
set(VTKEdge_VTK_DIR "/usr/lib/vtk-5.4")

# An install tree always provides one build configuration.
# A build tree may provide either one or multiple build
# configurations depending on the CMake generator used. Since
# this project can be used either from a build tree or an install tree it
# is useful for outside projects to know the configurations available.
# If this VTKEdgeConfig.cmake is in an install tree
# VTKEdge_CONFIGURATION_TYPES will be empty and VTKEdge_BUILD_TYPE
# will be set to the value of CMAKE_BUILD_TYPE used to build
# VTKEdge. If VTKEdgeConfig.cmake is in a build tree
# then VTKEdge_CONFIGURATION_TYPES and VTKEdge_BUILD_TYPE will
# have values matching CMAKE_CONFIGURATION_TYPES and CMAKE_BUILD_TYPE
# for that build tree (only one will ever be set).
set(VTKEdge_CONFIGURATION_TYPES )
set(VTKEdge_BUILD_TYPE Release)
